==> chicken_4.6.0.orig.tar.gz: chicken-4.6.0/chicken.import.scm <==
;;;; chicken.import.scm - import library for "chicken" module
;
; Copyright (c) 2008-2010, The Chicken Team
; All rights reserved.
;
; Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following
; conditions are met:
;
;   Redistributions of source code must retain the above copyright notice, this list of conditions and the following
;     disclaimer.
;   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following
;     disclaimer in the documentation and/or other materials provided with the distribution.
;   Neither the name of the author nor the names of its contributors may be used to endorse or promote
;     products derived from this software without specific prior written permission.
;
; THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS
; OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
; AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR
; CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
; CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
; SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
; THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
; OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
; POSSIBILITY OF SUCH DAMAGE.


(##sys#register-primitive-module
 'chicken
 '(abort
   add1
   argc+argv
   argv
   arithmetic-shift
   bit-set?
   bitwise-and
   bitwise-ior
   bitwise-not
   bitwise-xor
   blob->string
   blob-size
   blob?
   blob=?
   build-platform
   c-runtime
   call/cc
   case-sensitive
   char-name
   chicken-home
   chicken-version
   command-line-arguments
   condition-predicate
   condition-property-accessor
   condition?
   continuation-capture
   continuation-graft
   continuation-return
   continuation?
   copy-read-table
   cpu-time
   current-error-port
   current-exception-handler
   current-gc-milliseconds
   current-milliseconds
   current-read-table
   current-seconds
   define-reader-ctor
   delete-file
   enable-warnings
   directory-exists?
   errno
   error
   exit
   exit-handler
   expand
   extension-information
   feature?
   features
   file-exists?
   finite?
   fixnum-bits
   fixnum-precision
   fixnum?
   flonum-decimal-precision
   flonum-epsilon
   flonum-maximum-decimal-exponent
   flonum-maximum-exponent
   flonum-minimum-decimal-exponent
   flonum-minimum-exponent
   flonum-precision
   flonum-print-precision
   flonum-radix
   flonum?
   flush-output
   force-finalizers
   fp-
   fp*
   fp/
   fp+
   fp<
   fp<=
   fp=
   fp>
   fp>=
   fpabs
   fpacos
   fpasin
   fpatan
   fpatan2
   fpexp
   fpexpt
   fpfloor
   fpceiling
   fpcos
   fpinteger?
   fplog
   fpmax
   fpmin
   fpneg
   fpround
   fpsin
   fpsqrt
   fptan
   fptruncate
   fx-
   fx*
   fx/
   fx+
   fx<
   fx<=
   fx=
   fx>
   fx>=
   fxand
   fxeven?
   fxior
   fxmax
   fxmin
   fxmod
   fxneg
   fxnot
   fxodd?
   fxshl
   fxshr
   fxxor
   gc
   gensym
   get
   get-call-chain
   get-condition-property
   get-environment-variable
   get-keyword
   get-output-string
   get-properties
   getenv				; DEPRECATED
   getter-with-setter
   implicit-exit-handler
   keyword->string
   keyword-style
   keyword?
   load-library
   load-relative
   load-verbose
   machine-byte-order
   machine-type
   make-blob
   make-composite-condition
   make-parameter
   make-property-condition
   maximum-flonum
   memory-statistics
   minimum-flonum
   most-negative-fixnum
   most-positive-fixnum
   on-exit
   open-input-string
   open-output-string
   parentheses-synonyms
   port-closed?
   port-name
   port-position
   port?
   print
   print-call-chain
   print-error-message
   print*
   procedure-information
   program-name
   promise?
   put!
   register-feature!
   remprop!
   rename-file
   repl
   repl-prompt
   repository-path
   require
   reset
   reset-handler
   return-to-host
   reverse-list->string
   set-finalizer!
   set-gc-report!
   set-parameterized-read-syntax!
   set-port-name!
   set-read-syntax!
   set-sharp-read-syntax!
   setter
   signal
   signum
   singlestep
   software-type
   software-version
   string->blob
   string->keyword
   string->uninterned-symbol
   strip-syntax
   sub1
   symbol-append
   symbol-escape
   symbol-plist
   syntax-error
   system
   unregister-feature!
   vector-resize
   void
   warning
   eval-handler
   er-macro-transformer
   dynamic-load-libraries
   with-exception-handler)
 ##sys#chicken-macro-environment)       ;*** incorrect - won't work in compiled executable that does expansion

==> chicken_4.8.0.5.orig.tar.gz: chicken-4.8.0.5/chicken.import.scm <==
;;;; chicken.import.scm - import library for "chicken" module
;
; Copyright (c) 2008-2013, The Chicken Team
; All rights reserved.
;
; Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following
; conditions are met:
;
;   Redistributions of source code must retain the above copyright notice, this list of conditions and the following
;     disclaimer.
;   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following
;     disclaimer in the documentation and/or other materials provided with the distribution.
;   Neither the name of the author nor the names of its contributors may be used to endorse or promote
;     products derived from this software without specific prior written permission.
;
; THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS
; OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
; AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR
; CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
; CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
; SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
; THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
; OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
; POSSIBILITY OF SUCH DAMAGE.


(##sys#register-primitive-module
 'chicken
 '(abort
   add1
   argc+argv
   argv
   arithmetic-shift
   bit-set?
   bitwise-and
   bitwise-ior
   bitwise-not
   bitwise-xor
   blob->string
   blob-size
   blob?
   blob=?
   build-platform
   c-runtime
   call/cc
   case-sensitive
   char-name
   chicken-home
   chicken-version
   command-line-arguments
   condition-predicate
   condition-property-accessor
   condition?
   condition->list
   continuation-capture
   continuation-graft
   continuation-return
   continuation?
   copy-read-table
   cpu-time
   current-error-port
   current-exception-handler
   current-gc-milliseconds
   current-milliseconds
   current-read-table
   current-seconds
   define-reader-ctor
   delete-file
   directory-exists?
   enable-warnings
   equal=?
   er-macro-transformer
   errno
   error
   exit
   exit-handler
   expand
   extension-information
   feature?
   features
   file-exists?
   finite?
   fixnum-bits
   fixnum-precision
   fixnum?
   flonum-decimal-precision
   flonum-epsilon
   flonum-maximum-decimal-exponent
   flonum-maximum-exponent
   flonum-minimum-decimal-exponent
   flonum-minimum-exponent
   flonum-precision
   flonum-print-precision
   flonum-radix
   flonum?
   flush-output
   foldl
   foldr
   force-finalizers
   fp-
   fp*
   fp/
   fp+
   fp<
   fp<=
   fp=
   fp>
   fp>=
   fpabs
   fpacos
   fpasin
   fpatan
   fpatan2
   fpexp
   fpexpt
   fpfloor
   fpceiling
   fpcos
   fpinteger?
   fplog
   fpmax
   fpmin
   fpneg
   fpround
   fpsin
   fpsqrt
   fptan
   fptruncate
   fx-
   fx*
   fx/
   fx+
   fx<
   fx<=
   fx=
   fx>
   fx>=
   fxand
   fxeven?
   fxior
   fxmax
   fxmin
   fxmod
   fxneg
   fxnot
   fxodd?
   fxshl
   fxshr
   fxxor
   gc
   gensym
   get
   get-call-chain
   get-condition-property
   get-environment-variable
   get-keyword
   get-output-string
   get-properties
   getter-with-setter
   implicit-exit-handler
   ir-macro-transformer
   keyword->string
   keyword-style
   keyword?
   load-library
   load-relative
   load-verbose
   machine-byte-order
   machine-type
   make-blob
   make-composite-condition
   make-parameter
   make-property-condition
   maximum-flonum
   memory-statistics
   minimum-flonum
   module-environment
   most-negative-fixnum
   most-positive-fixnum
   on-exit
   open-input-string
   open-output-string
   parentheses-synonyms
   port-closed?
   port-name
   port-position
   port?
   print
   print-call-chain
   print-error-message
   print*
   procedure-information
   program-name
   promise?
   put!
   quit
   register-feature!
   remprop!
   rename-file
   repl
   repl-prompt
   repository-path
   require
   reset
   reset-handler
   return-to-host
   reverse-list->string
   set-finalizer!
   set-gc-report!
   set-parameterized-read-syntax!
   set-port-name!
   set-read-syntax!
   set-sharp-read-syntax!
   setter
   signal
   signum
   singlestep
   software-type
   software-version
   string->blob
   string->keyword
   string->uninterned-symbol
   strip-syntax
   sub1
   subvector
   symbol-append
   symbol-escape
   symbol-plist
   syntax-error
   system
   unregister-feature!
   vector-resize
   vector-copy!
   void
   warning
   eval-handler
   er-macro-transformer
   ir-macro-transformer
   dynamic-load-libraries
   with-exception-handler)
 ##sys#chicken-macro-environment)       ;XXX incorrect - won't work in compiled executable that does expansion
